@@ -6,7 +6,7 @@ use CGI::Util qw//;
 use Carp qw/carp croak/;
 use List::Util qw/first/;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 my $MODIFY = 'Modification of a read-only value attempted';
 
@@ -17,13 +17,20 @@ sub new {
     if ( ref $args[0] eq 'HASH' ) {
         @{ $self }{qw/header env/} = splice @args, 0, 2;
     }
-    else {
-        my %header;
+    elsif ( @args % 2 == 0 ) {
+        my $header = $self->{header} = {};
         while ( my ($key, $value) = splice @args, 0, 2 ) {
-            $header{ _lc($key) } = $value; # force overwrite
+            $header->{ _lc($key) } = $value; # force overwrite
         }
-
-        @{ $self }{qw/env header/} = ( delete $header{-env}, \%header );
+        if ( ref $header->{-env} eq 'HASH' ) {
+            $self->{env} = delete $header->{-env};
+        }
+    }
+    elsif ( @args == 1 ) {
+        $self->{header}->{-type} = shift @args;
+    }
+    else {
+        croak 'Odd number of elements in hash assignment';
     }
 
     $self->{env} ||= \%ENV;
@@ -107,7 +114,7 @@ my %set = (
     },
 );
 
-sub set {
+sub set { # unstable
     my $self = shift;
     my $key = _lc( shift );
     my $header = $self->{header};
@@ -320,7 +327,7 @@ sub FIRSTKEY {
     ( $self->{iterator} = sub { shift @fields } )->();
 }
 
-sub NEXTKEY { $_[0]->{iterator}() }
+sub NEXTKEY { $_[0]->{iterator}->() }
 
 BEGIN { *_expires = \&CGI::Util::expires }
 
@@ -500,6 +507,12 @@ you can specify '-env' property which represents your current environment:
   $h->header; # => { -type => 'text/plain' }
   $h->env;    # => \%ENV
 
+=item $header = CGI::Header->new( $media_type )
+
+A shortcut for:
+
+  my $h = CGI::Header->new({ -type => $media_type });
+
 =back
 
 =head2 INSTANCE METHODS
@@ -863,7 +876,7 @@ See also L<perltie>.
 
 See also L<CGI::Emulate::PSGI>, L<CGI::PSGI>.
 
-=head2 DEPENDENCIES
+=head1 DEPENDENCIES
 
 This module is compatible with CGI.pm 3.51 or higher.
 
@@ -892,7 +905,7 @@ You can set the Content-Type header to neither undef nor an empty:
 
 Use delete() instead:
 
-  $header->delete( 'Content-Type' );
+  $header->delete('Content-Type');
 
 =item Date
 
@@ -900,13 +913,11 @@ If one of the following conditions is met, the Date header will be set
 automatically, and also the header field will become read-only:
 
   if ( $header->nph or $header->get('Set-Cookie') or $header->expires ) {
-      my $date = $header->get( 'Date' ); # => HTTP-Date (current time)
+      my $date = $header->get('Date'); # => HTTP-Date (current time)
+      $header->set( 'Date' => 'Thu, 25 Apr 1999 00:40:33 GMT' ); # wrong
+      $header->delete('Date'); # wrong
   }
 
-  # wrong
-  $header->set( 'Date' => 'Thu, 25 Apr 1999 00:40:33 GMT' );
-  $header->delete( 'Date' );
-
 =item Expires
 
 You can't assign to the Expires header directly
@@ -915,12 +926,12 @@ because the following behavior will surprise us:
   # wrong
   $header->set( 'Expires' => '+3d' );
 
-  my $value = $header->get( 'Expires' );
+  my $value = $header->get('Expires');
   # => "Thu, 25 Apr 1999 00:40:33 GMT" (not "+3d")
 
 Use expires() instead:
 
-  $header->expires( '+3d' );
+  $header->expires('+3d');
 
 =item P3P
 
@@ -939,19 +950,19 @@ If the following condition is met, the Server header will be set
 automatically, and also the header field will become read-only: 
 
   if ( $header->nph ) {
-      my $server = $header->get( 'Server' );
+      my $server = $header->get('Server');
       # => $header->env->{SERVER_SOFTWARE}
+
+      $header->set( 'Server' => 'Apache/1.3.27 (Unix)' ); # wrong
+      $header->delete( 'Server' ); # wrong
   }
 
-  # wrong
-  $header->set( 'Server' => 'Apache/1.3.27 (Unix)' );
-  $header->delete( 'Server' );
 
 =back
 
 =head1 SEE ALSO
 
-L<CGI>, L<Plack::Util>, L<HTTP::Headers>
+L<CGI>, L<Plack::Util>::headers(), L<HTTP::Headers>
 
 =head1 BUGS
 
